==> anchor-experiment-0.2.1-sources.jar: org/anchoranalysis/experiment/log/MultipleLoggers.java <==
/*-
 * #%L
 * anchor-experiment
 * %%
 * Copyright (C) 2010 - 2020 Owen Feehan, ETH Zurich, University of Zurich, Hoffmann-La Roche
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */

package org.anchoranalysis.experiment.log;

import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import org.anchoranalysis.core.exception.OperationFailedException;
import org.anchoranalysis.core.log.MessageLogger;

/**
 * Logs messages to multiple other loggers.
 *
 * @author Owen Feehan
 */
public class MultipleLoggers implements StatefulMessageLogger {

    private final List<StatefulMessageLogger> list;

    /**
     * Creates with a stream of loggers.
     *
     * @param stream the stream of loggers.
     */
    public MultipleLoggers(Stream<StatefulMessageLogger> stream) {
        list = stream.collect(Collectors.toList());
    }

    @Override
    public void start() throws OperationFailedException {
        for (StatefulMessageLogger logger : list) {
            assert logger != null;
            logger.start();
        }
    }

    @Override
    public void log(String message) {
        for (StatefulMessageLogger logger : list) {
            assert logger != null;
            logger.log(message);
        }
    }

    @Override
    public void close(boolean successful, boolean warningOccurred) {
        for (StatefulMessageLogger logger : list) {
            logger.close(successful, warningOccurred);
        }
    }

    @Override
    public void logFormatted(String formatString, Object... args) {
        for (MessageLogger logger : list) {
            logger.logFormatted(formatString, args);
        }
    }
}

==> anchor-experiment-1.0.0-sources.jar: org/anchoranalysis/experiment/log/MultipleLoggers.java <==
/*-
 * #%L
 * anchor-experiment
 * %%
 * Copyright (C) 2010 - 2020 Owen Feehan, ETH Zurich, University of Zurich, Hoffmann-La Roche
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */

package org.anchoranalysis.experiment.log;

import java.util.List;
import java.util.stream.Stream;
import org.anchoranalysis.core.exception.OperationFailedException;
import org.anchoranalysis.core.log.MessageLogger;

/**
 * Logs messages to multiple other loggers.
 *
 * @author Owen Feehan
 */
public class MultipleLoggers implements StatefulMessageLogger {

    private final List<StatefulMessageLogger> list;

    /**
     * Creates with a stream of loggers.
     *
     * @param stream the stream of loggers.
     */
    public MultipleLoggers(Stream<StatefulMessageLogger> stream) {
        list = stream.toList();
    }

    @Override
    public void start() throws OperationFailedException {
        for (StatefulMessageLogger logger : list) {
            assert logger != null;
            logger.start();
        }
    }

    @Override
    public void log(String message) {
        for (StatefulMessageLogger logger : list) {
            assert logger != null;
            logger.log(message);
        }
    }

    @Override
    public void close(boolean successful, boolean warningOccurred) {
        for (StatefulMessageLogger logger : list) {
            logger.close(successful, warningOccurred);
        }
    }

    @Override
    public void logFormatted(String formatString, Object... args) {
        for (MessageLogger logger : list) {
            logger.logFormatted(formatString, args);
        }
    }
}
